<?php
namespace KissImageHover\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;

/**
 * Elementor
 *
 * Elementor widget
 *
 * @since 1.0.0
 */
class kiss__image_hover__hover_image extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'hover_image';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Hover Image', 'image-hover' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image-rollover';
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ '' ];
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kiss-image-hover-category' ];
	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'image-hover' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_control(
			'content',
			[
				'label' => esc_html__( 'Content Text', 'image-hover' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => esc_html__( 'Dream &lt;span&gtHome&lt;/span&gt', 'image-hover' ),
				'placeholder' => esc_html__( 'For Effect3, add &lt;i&gtNow&lt;/i&gt ', 'image-hover' ),
			]
		);
		$this->add_control(
			'content_hover',
			[
				'label' => esc_html__( 'Content Hover Text', 'image-hover' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Lorem ipsum dolor sit amet', 'image-hover' ),
				'placeholder' => esc_html__( 'Type your content here', 'image-hover' ),
			]
		);
		
 	    $this->add_control(
			'image',
			[
				'label' => esc_html__( 'Image', 'image-hover' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [ 'url' => \Elementor\Utils::get_placeholder_image_src() ],
			]
		);
		
		$this->add_control(
			'link_text',
			[
				'label' => esc_html__( 'Link Text', 'image-hover' ),
				'type'  => \Elementor\Controls_Manager::TEXT,
			]
		);
		
		$this->add_control(
			'link_url',
			[
				'label' => esc_html__( 'URL', 'image-hover' ),
				'type'  => \Elementor\Controls_Manager::URL,
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_content1',
			[
				'label' => esc_html__( 'Effect', 'image-hover' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_control(
			'effect',
			array(
			  'label'       => esc_html__('Choose Image Effect', 'image-hover'),
			  'type'        => \Elementor\Controls_Manager::SELECT,
			  'default'     => 'effect-milo',
			  'label_block' => true,
			  'options' => array(
				'effect-lily' => esc_html__('Effect 1', 'image-hover'),
				'effect-sadie' => esc_html__('Effect 2', 'image-hover'),
				'effect-honey' => esc_html__('Effect 3', 'image-hover'),
				'effect-marley' => esc_html__('Effect 4', 'image-hover'),
				'effect-sarah' => esc_html__('Effect 5', 'image-hover'),
				'effect-chico' => esc_html__('Effect 6', 'image-hover'),
				'effect-milo' => esc_html__('Effect 7', 'image-hover'),
				'effect-julia' => esc_html__('Effect 8', 'image-hover'),
				'effect-apollo' => esc_html__('Effect 9', 'image-hover'),
				'effect-jazz' => esc_html__('Effect 10', 'image-hover'),
				'effect-lexi' => esc_html__('Effect 11', 'image-hover'),
				'effect-roxy' => esc_html__('Effect 12', 'image-hover'),
			  )
			)
		  );	
		
		$this->end_controls_section();
		
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$image     = $settings['image'];
		$style    = $settings['style'];
		$effect    = $settings['effect'];
		
		
	?>
	<div class="grid--hover <?php echo sprintf($settings['style']); ?>">
		<figure class="<?php echo esc_html($settings['effect']); ?>">
			<img src="<?php echo esc_html($settings['image']['url']); ?>" alt=""/>
			<figcaption>
				<div>
					<h2><?php echo sprintf($settings['content']); ?></h2>
					<p><?php echo esc_html($settings['content_hover']); ?></p>
				</div>
				<?php if ( ! empty( $settings['link_url']['url'] ) ) { ?>
					<a href="<?php echo esc_url($settings['link_url']['url']); ?>"><?php echo esc_html($settings['link_text']); ?></a>
				<?php } ?>
			</figcaption>			
		</figure>
	</div>
<?php			
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function content_template() {}
	
}
