<?php
namespace KissImageHover\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;

/**
 * Elementor
 *
 * Elementor widget
 *
 * @since 1.0.0
 */
class kiss__image_hover__tilt_image extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tilt_image';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Hover Tilt Image', 'image-hover' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image-rollover';
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'imagesloaded' , 'anime' , 'kiss-tilt' ];
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kiss-image-hover-category' ];
	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'image-hover' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_control(
			'content',
			[
				'label' => esc_html__( 'Content Text', 'image-hover' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( '', 'image-hover' ),
				'placeholder' => esc_html__( 'Type your content here', 'image-hover' ),
			]
		);
		$this->add_control(
			'content_hover',
			[
				'label' => esc_html__( 'Content Sub-Text', 'image-hover' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( '', 'image-hover' ),
				'placeholder' => esc_html__( 'Type your content here', 'image-hover' ),
			]
		);
		
 	    $this->add_control(
			'image',
			[
				'label' => esc_html__( 'Image', 'image-hover' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [ 'url' => \Elementor\Utils::get_placeholder_image_src() ],
			]
		);
		
		
		$this->add_control(
			'link_url',
			[
				'label' => esc_html__( 'URL', 'image-hover' ),
				'type'  => \Elementor\Controls_Manager::URL,
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_content1',
			[
				'label' => esc_html__( 'Effect', 'image-hover' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_control(
			'effect',
			array(
			  'label'       => esc_html__('Choose Tilt Effect', 'image-hover'),
			  'type'        => \Elementor\Controls_Manager::SELECT,
			  'default'     => 'tilter--1',
			  'label_block' => true,
			  'options' => array(
				'tilter--1' => esc_html__('Tilt 1', 'image-hover'),
				'tilter--2' => esc_html__('Tilt 2', 'image-hover'),
				'tilter--3' => esc_html__('Tilt 3', 'image-hover'),
				'tilter--4' => esc_html__('Tilt 4', 'image-hover'),
				'tilter--5' => esc_html__('Tilt 5', 'image-hover'),
				'tilter--6' => esc_html__('Tilt 6', 'image-hover'),
				'tilter--7' => esc_html__('Tilt 7', 'image-hover'),
				'tilter--8' => esc_html__('Tilt 8', 'image-hover'),
				
			  )
			)
		  );	
		
		$this->end_controls_section();
		
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$effect    = $settings['effect'];
	?>
	<div class="tilt--image">
		<a href="<?php echo esc_url($settings['link_url']['url']); ?>" class="tilter <?php echo esc_html($settings['effect']); ?>">
			<figure class="tilter__figure">
				<img class="tilter__image" src="<?php echo esc_html($settings['image']['url']); ?>" alt="img01" />
				<div class="tilter__deco tilter__deco--shine"><div></div></div>
				<figcaption class="tilter__caption">
					<h3 class="tilter__title"><?php echo sprintf($settings['content']); ?></h3>
					<p class="tilter__description"><?php echo esc_html($settings['content_hover']); ?></p>
				</figcaption>
				<?php if ($effect !== 'tilter--3') { ?>
				<svg class="tilter__deco tilter__deco--lines" viewBox="0 0 300 415">
					<path d="M20.5,20.5h260v375h-260V20.5z" />
				</svg>
				<?php } ?>
			</figure>
		</a>
	</div>
<?php			
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function content_template() {}
	
}
